==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE36S.sql <==
/****************************************************************************/
/* GE36 ( ﾊﾞｯﾁ送信ｴﾗｰﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE36 (
   PARA_KEY     VARCHAR2 (    9 )                   NOT NULL            /*  10 ﾊﾟﾗﾒｰﾀｷｰ     */
 , SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  20 ｼｽﾃﾑID       */
 , ERRMSG       VARCHAR2 ( 4000 )                                       /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 登録日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE36S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE36T00 
  BEFORE INSERT ON GE36
  FOR EACH ROW 
  BEGIN 
    SELECT GE36S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE36S.sql <==
/****************************************************************************/
/* GE36 ( ﾊﾞｯﾁ送信ｴﾗｰﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GE36 (
   PARA_KEY     VARCHAR2 (    9 )                   NOT NULL            /*  10 ﾊﾟﾗﾒｰﾀｷｰ     */
 , SYSTEM_ID    VARCHAR2 (   10 )                   NOT NULL            /*  20 ｼｽﾃﾑID       */
 , ERRMSG       VARCHAR2 ( 4000 )                                       /*  30 ｴﾗｰﾒｯｾｰｼﾞ    */
 , UNIQ         NUMBER   (    9 )       DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (    1 )       DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (   14 )                                       /* 820 作成日時     */
 , PGSET        VARCHAR2 (   10 )                                       /* 830 作成PG       */
 , PGPSET       VARCHAR2 (   10 )                                       /* 840 作成親PG     */
 , USRSET       VARCHAR2 (   10 )                                       /* 850 作成者       */
 , DYUPD        VARCHAR2 (   14 )                                       /* 860 更新日時     */
 , PGUPD        VARCHAR2 (   10 )                                       /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (   10 )                                       /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (   10 )                                       /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );


CREATE SEQUENCE GE36S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;


CREATE OR REPLACE TRIGGER GE36T00 
  BEFORE INSERT ON GE36
  FOR EACH ROW 
  BEGIN 
    SELECT GE36S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
